@@ -19,7 +19,6 @@
 #include <QTimer>
 
 #include <KConfigGroup>
-#include <KDirWatch>
 #include <KImageCache>
 
 #include "debug_p.h"
@@ -30,7 +29,7 @@ ImageSet::ImageSet(QObject *parent)
     : QObject(parent)
 {
     if (!ImageSetPrivate::globalImageSet) {
-        ImageSetPrivate::globalImageSet = new ImageSetPrivate;
+        ImageSetPrivate::globalImageSet = new ImageSetPrivate(QString());
         if (QCoreApplication::instance()) {
             connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit, ImageSetPrivate::globalImageSet, &ImageSetPrivate::onAppExitCleanup);
         }
@@ -46,7 +45,7 @@ ImageSet::ImageSet(const QString &imageSetName, const QString &basePath, QObject
 {
     auto &priv = ImageSetPrivate::themes[imageSetName];
     if (!priv) {
-        priv = new ImageSetPrivate;
+        priv = new ImageSetPrivate(basePath);
         if (QCoreApplication::instance()) {
             connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit, priv, &ImageSetPrivate::onAppExitCleanup);
         }
@@ -60,13 +59,12 @@ ImageSet::ImageSet(const QString &imageSetName, const QString &basePath, QObject
     d->cacheImageSet = false;
     if (!basePath.isEmpty()) {
         d->basePath = basePath;
-        if (!d->basePath.endsWith(QDir::separator())) {
-            d->basePath += QDir::separator();
+        if (!d->basePath.endsWith(u'/')) {
+            d->basePath += u'/';
         }
     }
     d->setImageSetName(imageSetName, false);
     d->cacheImageSet = useCache;
-    d->fixedName = true;
     connect(d, &ImageSetPrivate::imageSetChanged, this, &ImageSet::imageSetChanged);
 }
 
@@ -81,7 +79,8 @@ ImageSet::~ImageSet()
         }
     } else {
         if (!d->ref.deref()) {
-            delete ImageSetPrivate::themes.take(d->imageSetName);
+            ImageSetPrivate::themes.remove(d->imageSetName);
+            delete d;
         }
     }
 }
@@ -93,8 +92,8 @@ void ImageSet::setBasePath(const QString &basePath)
     }
 
     d->basePath = basePath;
-    if (!d->basePath.endsWith(QDir::separator())) {
-        d->basePath += QDir::separator();
+    if (!d->basePath.endsWith(u'/')) {
+        d->basePath += u'/';
     }
 
     // Don't use scheduleImageSetChangeNotification as we want things happening immediately there,
@@ -130,6 +129,8 @@ void ImageSet::setImageSetName(const QString &imageSetName)
     }
 
     if (d != ImageSetPrivate::globalImageSet) {
+        const QString basePath = d->basePath;
+
         disconnect(QCoreApplication::instance(), nullptr, d, nullptr);
         if (!d->ref.deref()) {
             delete ImageSetPrivate::themes.take(d->imageSetName);
@@ -137,7 +138,7 @@ void ImageSet::setImageSetName(const QString &imageSetName)
 
         auto &priv = ImageSetPrivate::themes[imageSetName];
         if (!priv) {
-            priv = new ImageSetPrivate;
+            priv = new ImageSetPrivate(basePath);
             if (QCoreApplication::instance()) {
                 connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit, priv, &ImageSetPrivate::onAppExitCleanup);
             }
@@ -230,6 +231,7 @@ bool ImageSet::currentImageSetHasImage(const QString &name) const
     return path.contains(d->basePath % d->imageSetName);
 }
 
+#if KSVG_BUILD_DEPRECATED_SINCE(6, 21)
 void ImageSet::setUseGlobalSettings(bool useGlobal)
 {
     if (d->useGlobal == useGlobal) {
@@ -240,24 +242,30 @@ void ImageSet::setUseGlobalSettings(bool useGlobal)
     d->cfg = KConfigGroup();
     d->imageSetName.clear();
 }
+#endif
 
+#if KSVG_BUILD_DEPRECATED_SINCE(6, 21)
 bool ImageSet::useGlobalSettings() const
 {
     return d->useGlobal;
 }
+#endif
 
+#if KSVG_BUILD_DEPRECATED_SINCE(6, 21)
 void ImageSet::setCacheLimit(int kbytes)
 {
     d->cacheSize = kbytes;
     delete d->pixmapCache;
     d->pixmapCache = nullptr;
 }
+#endif
 
+#if KSVG_BUILD_DEPRECATED_SINCE(6, 21)
 KPluginMetaData ImageSet::metadata() const
 {
     return d->pluginMetaData;
 }
-
+#endif
 }
 
 #include "moc_imageset.cpp"
